==> kde4pim_3.92.0.orig.tar.gz: kdepim-3.92.0/kpilot/conduits/vcalconduit/vcal-setupbase.h <==
#ifndef _KPILOT_VCAL_SETUPBASE_H
#define _KPILOT_VCAL_SETUPBASE_H
/* vcal-setup.h                       KPilot
**
** Copyright (C) 2002-2003 Reinhold Kainhofer
** Copyright (C) 2001 by Dan Pilone
**
** It also defines the class for the behavior of the setup dialog.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
** MA 02110-1301, USA.
*/

/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include "plugin.h"

#warning this include is for the Ui namespace, there is probably a better way.
#include "ui_setup_base.h"

class Ui::VCalWidget;
class VCalConduitSettings;

class VCalWidgetSetupBase : public ConduitConfigBase
{
public:
	VCalWidgetSetupBase(QWidget *);
	virtual ~VCalWidgetSetupBase();

	virtual void load();
	virtual void commit();

protected:
	virtual VCalConduitSettings*config()=0;
	Ui::VCalWidget *fConfigWidget;
};

#endif

==> kde4pim_3.94.0.orig.tar.gz: kdepim-3.94.0/kpilot/conduits/vcalconduit/vcal-setupbase.h <==
#ifndef _KPILOT_VCAL_SETUPBASE_H
#define _KPILOT_VCAL_SETUPBASE_H
/* vcal-setup.h                       KPilot
**
** Copyright (C) 2002-2003 Reinhold Kainhofer
** Copyright (C) 2001 by Dan Pilone
**
** It also defines the class for the behavior of the setup dialog.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
** MA 02110-1301, USA.
*/

/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include "plugin.h"

#warning this include is for the Ui namespace, there is probably a better way.
#include "ui_setup_base.h"

class Ui::VCalWidget;
class VCalConduitSettings;

class VCalWidgetSetupBase : public ConduitConfigBase
{
Q_OBJECT
public:
	VCalWidgetSetupBase(QWidget *, const QVariantList & = QVariantList() );
	virtual ~VCalWidgetSetupBase();

	virtual void load();
	virtual void commit();

protected:
	virtual VCalConduitSettings*config()=0;
	Ui::VCalWidget fConfigWidget;
};

#endif
